@@ -1,5 +1,6 @@
 import dataclasses
 import os
+import pathlib
 import time
 import typing
 from xml.etree import ElementTree as ET  # noqa: S405
@@ -14,6 +15,7 @@ from opentelemetry.semconv._incubating.attributes import vcs_attributes  # noqa:
 from opentelemetry.semconv.trace import SpanAttributes
 import opentelemetry.trace.span
 
+from mergify_cli import console
 from mergify_cli.ci import detector
 
 
@@ -25,6 +27,29 @@ class InvalidJunitXMLError(Exception):
     details: str
 
 
+async def files_to_spans(
+    files: tuple[str, ...],
+    test_language: str | None = None,
+    test_framework: str | None = None,
+) -> list[ReadableSpan]:
+    spans = []
+
+    run_id = ID_GENERATOR.generate_span_id().to_bytes(8, "big").hex()
+    console.print(f"MERGIFY_TEST_RUN_ID={run_id}")
+
+    for filename in files:
+        spans.extend(
+            await junit_to_spans(
+                run_id,
+                pathlib.Path(filename).read_bytes(),
+                test_language=test_language,
+                test_framework=test_framework,
+            ),
+        )
+
+    return spans
+
+
 async def junit_to_spans(
     run_id: str,
     xml_content: bytes,
@@ -68,6 +93,9 @@ async def junit_to_spans(
             "MERGIFY_TEST_JOB_NAME"
         ]
 
+    if (pipeline_name := detector.get_pipeline_name()) is not None:
+        resource_attributes[cicd_attributes.CICD_PIPELINE_NAME] = pipeline_name
+
     if (job_name := detector.get_job_name()) is not None:
         resource_attributes[cicd_attributes.CICD_PIPELINE_TASK_NAME] = job_name
 
@@ -156,6 +184,7 @@ async def junit_to_spans(
             attributes = {
                 "test.scope": "case",
                 "test.case.name": test_name,
+                "code.function.name": test_name,
             }
 
             if (filename := testcase.get("file")) is not None:
