@@ -11,6 +11,7 @@ from mergify_cli.ci import junit
 
 
 @mock.patch.object(detector, "get_ci_provider", return_value="github_actions")
+@mock.patch.object(detector, "get_pipeline_name", return_value="PIPELINE")
 @mock.patch.object(detector, "get_job_name", return_value="JOB")
 @mock.patch.object(
     detector,
@@ -31,6 +32,7 @@ from mergify_cli.ci import junit
 )
 async def test_parse(
     _get_ci_provider: mock.Mock,
+    _get_pipeline_name: mock.Mock,
     _get_job_name: mock.Mock,
     _get_cicd_pipeline_runner_name: mock.Mock,
     _get_cicd_pipeline_run_id: mock.Mock,
@@ -54,6 +56,7 @@ async def test_parse(
     )
     resource_attributes = {
         "test.run.id": run_id,
+        "cicd.pipeline.name": "PIPELINE",
         "cicd.pipeline.task.name": "JOB",
         "cicd.pipeline.run.id": 123,
         "cicd.pipeline.run.attempt": 1,
@@ -124,6 +127,7 @@ async def test_parse(
         {
             "attributes": {
                 "test.case.name": "Tests.Registration.testCase1",
+                "code.function.name": "Tests.Registration.testCase1",
                 "test.case.result.status": "passed",
                 "test.scope": "case",
                 "test.framework": "unittest",
@@ -152,6 +156,7 @@ async def test_parse(
         {
             "attributes": {
                 "test.case.name": "Tests.Registration.testCase2",
+                "code.function.name": "Tests.Registration.testCase2",
                 "test.case.result.status": "skipped",
                 "test.scope": "case",
                 "test.framework": "unittest",
@@ -183,6 +188,7 @@ async def test_parse(
                 "exception.stacktrace": "bip, bip, bip, error!",
                 "exception.type": "ValueError",
                 "test.case.name": "Tests.Registration.testCase3",
+                "code.function.name": "Tests.Registration.testCase3",
                 "test.case.result.status": "failed",
                 "test.scope": "case",
                 "test.framework": "unittest",
@@ -238,6 +244,7 @@ async def test_parse(
         {
             "attributes": {
                 "test.case.name": "Tests.Authentication.testCase7",
+                "code.function.name": "Tests.Authentication.testCase7",
                 "test.case.result.status": "passed",
                 "test.scope": "case",
                 "test.framework": "unittest",
@@ -266,6 +273,7 @@ async def test_parse(
         {
             "attributes": {
                 "test.case.name": "Tests.Authentication.testCase8",
+                "code.function.name": "Tests.Authentication.testCase8",
                 "test.case.result.status": "passed",
                 "test.scope": "case",
                 "test.framework": "unittest",
@@ -297,6 +305,7 @@ async def test_parse(
                 "exception.stacktrace": "Such a mess, the failure is unrecoverable",
                 "exception.type": "AssertionError",
                 "test.case.name": "Tests.Authentication.testCase9",
+                "code.function.name": "Tests.Authentication.testCase9",
                 "test.case.result.status": "failed",
                 "test.scope": "case",
                 "test.framework": "unittest",
@@ -329,6 +338,7 @@ async def test_parse(
                 "With a second line!",
                 "exception.type": "ZeroDivisionError",
                 "test.case.name": "Tests.Permission.testCase10",
+                "code.function.name": "Tests.Permission.testCase10",
                 "test.case.result.status": "failed",
                 "test.scope": "case",
                 "test.framework": "unittest",
@@ -384,6 +394,7 @@ async def test_parse(
         {
             "attributes": {
                 "test.case.name": "Tests.Authentication.Login.testCase4",
+                "code.function.name": "Tests.Authentication.Login.testCase4",
                 "test.case.result.status": "passed",
                 "test.scope": "case",
                 "test.framework": "unittest",
@@ -415,6 +426,7 @@ async def test_parse(
                 "exception.stacktrace": "bad syntax, bad!",
                 "exception.type": "SyntaxError",
                 "test.case.name": "Tests.Authentication.Login.testCase5",
+                "code.function.name": "Tests.Authentication.Login.testCase5",
                 "test.case.result.status": "failed",
                 "test.scope": "case",
                 "test.framework": "unittest",
@@ -443,6 +455,7 @@ async def test_parse(
         {
             "attributes": {
                 "test.case.name": "Tests.Authentication.Login.testCase6",
+                "code.function.name": "Tests.Authentication.Login.testCase6",
                 "test.case.result.status": "passed",
                 "test.scope": "case",
                 "test.framework": "unittest",
